@@ -185,8 +185,7 @@ class AnonymousStrategy(Strategy):
         cdp: CDP,
         search_url: str,
         query: Query,
-        location: str,
-        apply_link: bool
+        location: str
     ) -> None:
         """
         Run scraper
